from setuptools import setup

setup(
    name='dbxs',
    version='0.0.1',
    description="Ignore this, just testing.",
    long_description='',
    author='me',
    author_email='code@glyph.im',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)
